#' sigr: Format Significance Summaries for Reports
#'
#' Succinctly format significance summaries of
#' various models and tests (F-test, Chi-Sq-test, Fisher-test, T-test, and rank-significance).  The main purpose is unified reporting and planning
#' of experimental results, working around issue such as the difficulty of
#' extracting model summary facts (such as with 'lm'/'glm').  This package also
#' includes empirical tests, such as bootstrap estimates.
#'

#' To learn more about sigr, please start with the vignette:
#' \code{vignette('sigrFormatting','sigr')}
#'
"_PACKAGE"

#' @importFrom wrapr stop_if_dot_args
NULL
